# fuggle
Fugue for Kaggle users


## Release History

### 0.2.8

* Update tune init

### 0.2.7

* Update fugue and tune versions

### 0.2.6

* Update tune version

### 0.2.5

* Update tune version

### 0.2.4

* Update tune version

### 0.2.3

* Add config shortcut

### 0.2.2

* Disable Fugue SQL highlighting on Kaggle, they no longer support it

### 0.2.1

* Upgrade fugue dependency and add tune dependency and support

### 0.2.0

* Upgrade fugue dependency

### 0.1.8

* Upgrade fugue dependency, handle breaking changes

### 0.1.7

* Refactor fuggle based on fugue_notebook

### 0.1.6

* Fix sql global variable import

### 0.1.5

* Disable pandas udf (kaggle upgraded to java 11, spark is hard to config)

### 0.1.2

* Remove print

### 0.1.1

* Add `group` to plot
* Add default checkpoint path

### 0.1.0

* Add Dag class for convenience
* Updated highlights

### 0.0.9

* Add dask support

### 0.0.8

* Make setup function configurable

### 0.0.7

* Add Kaggle sqlite data handling logic

### 0.0.6

* Fix rendering issue

### 0.0.5

* Fine tune of the experience

### 0.0.4

* Add plot extensions

### <= 0.0.3

* Setup basic functions
